import io
import re
import typing
import wave
from os.path import join
from pathlib import Path
from threading import Lock

from mimic3_tts import AudioResult, Mimic3Settings, Mimic3TextToSpeechSystem, SSMLSpeaker
from ovos_plugin_manager.tts import TTS
from ovos_utils.xdg_utils import xdg_data_home


class Mimic3TTSPlugin(TTS):
    """Mycroft interface to Mimic3."""
    default_voices = {
        # TODO add default voice for every lang
        "en": "en_US/cmu-arctic_low",
        "en-uk": "en_UK/apope_low",
        "en-gb": "en_UK/apope_low",
        "de": "de_DE/thorsten_low",
        "bn": "bn/multi_low",
        "af": "af_ZA/google-nwu_low",
        "es": "es_ES/m-ailabs_low",
        "fa": "fa/haaniye_low",
        "fi": "fi_FI/harri-tapani-ylilammi_low",
        "fr": "fr_FR/m-ailabs_low",
        "it": "it_IT/mls_low",
        "ko": "ko_KO/kss_low",
        "nl": "nl/bart-de-leeuw_low",
        "pl": "pl_PL/m-ailabs_low",
        "ru": "ru_RU/multi_low",
        "uk": "uk_UK/m-ailabs_low"
    }

    def __init__(self, lang="en-us", config=None):
        ssml_tags = [
            "speak",
            "s",
            "w",
            "voice",
            "prosody",
            "say-as",
            "break",
            "sub",
            "phoneme",
        ]
        super().__init__(lang, config, ssml_tags=ssml_tags)
        self.lock = Lock()
        self.lang = self.config.get("language") or self.lang
        preload_voices = self.config.get("preload_voices") or []
        preload_langs = self.config.get("preload_langs") or [self.lang]
        default_voice = self.config.get("voice")
        voice_dl = self.config.get("voices_download_dir") or join(xdg_data_home(), "mycroft", "mimic3", "voices")
        voice_dirs = self.config.get("voices_directories") or [voice_dl]

        self.tts = Mimic3TextToSpeechSystem(
            Mimic3Settings(
                voice=default_voice,
                language=self.lang,
                voices_directories=voice_dirs,
                voices_url_format=self.config.get("voices_url_format"),
                speaker=self.config.get("speaker"),
                length_scale=self.config.get("length_scale"),
                noise_scale=self.config.get("noise_scale"),
                noise_w=self.config.get("noise_w"),
                voices_download_dir=voice_dl,
                use_deterministic_compute=self.config.get(
                    "use_deterministic_compute", False
                ),
            )
        )

        if default_voice:
            self.default_voices[self.lang] = default_voice

        for voice in preload_voices:
            self.tts.preload_voice(voice)

        for lang in preload_langs:
            if lang not in self.default_voices:
                lang = lang.split("-")[0]
            voice = self.default_voices.get(lang)
            if voice:
                self.tts.preload_voice(voice)

    def get_tts(self, sentence, wav_file, lang=None, voice=None, speaker=None):
        """Synthesize audio using Mimic3 on device"""

        # support optional args for lang/voice/etc per request
        # a lock is used because we modify internal self.tts state
        with self.lock:
            def_speaker = self.tts.speaker
            def_voice = self.tts.voice
            if voice:
                self.tts.voice = voice
            elif lang:
                if lang not in self.default_voices:
                    lang = lang.split("-")[0]
                if lang in self.default_voices:
                    self.tts.voice = self.default_voices[lang]
            if speaker:
                self.tts.speaker = speaker

            # self.tts.settings.length_scale = length_scale
            # self.tts.settings.noise_scale = noise_scale
            # self.tts.settings.noise_w = noise_w

            sentence, ssml = self._apply_text_hacks(sentence)
            wav_bytes = self._mimic3_synth(sentence, ssml=ssml)

            self.tts.voice = def_voice
            self.tts.speaker = def_speaker

        # Write WAV to file
        Path(wav_file).write_bytes(wav_bytes)

        return (wav_file, None)

    @property
    def available_languages(self) -> set:
        """Return languages supported by this TTS implementation in this state
        This property should be overridden by the derived class to advertise
        what languages that engine supports.
        Returns:
            set: supported languages
        """
        return set(Mimic3TTSPluginConfig.keys())

    @staticmethod
    def _apply_text_hacks(sentence: str) -> typing.Tuple[str, bool]:
        """Mycroft-specific workarounds for text.

        Returns: (text, ssml)
        """

        # HACK: Mycroft gives "eight a.m.next sentence" sometimes
        sentence = sentence.replace(" a.m.", " a.m. ")
        sentence = sentence.replace(" p.m.", " p.m. ")

        # A I -> A.I.
        sentence = re.sub(
            r"\b([A-Z](?: |$)){2,}",
            lambda m: m.group(0).strip().replace(" ", ".") + ". ",
            sentence,
        )

        # Assume SSML if sentence begins with an angle bracket
        ssml = sentence.strip().startswith("<")

        # HACK: Speak single letters from Mycroft (e.g., "A;")
        if (len(sentence) == 2) and sentence.endswith(";"):
            letter = sentence[0]
            ssml = True
            sentence = f'<say-as interpret-as="spell-out">{letter}</say-as>'
        else:
            # HACK: 'A' -> spell out
            sentence, subs_made = re.subn(
                r"'([A-Z])'",
                r'<say-as interpret-as="spell-out">\1</say-as>',
                sentence,
            )
            if subs_made > 0:
                ssml = True

        return (sentence, ssml)

    def _mimic3_synth(self, text: str, ssml: bool = False) -> bytes:
        """Synthesize audio from text and return WAV bytes"""
        with io.BytesIO() as wav_io:
            wav_file: wave.Wave_write = wave.open(wav_io, "wb")
            wav_params_set = False

            with wav_file:
                try:
                    if ssml:
                        # SSML
                        results = SSMLSpeaker(self.tts).speak(text)
                    else:
                        # Plain text
                        self.tts.begin_utterance()
                        self.tts.speak_text(text)
                        results = self.tts.end_utterance()

                    for result in results:
                        # Add audio to existing WAV file
                        if isinstance(result, AudioResult):
                            if not wav_params_set:
                                wav_file.setframerate(result.sample_rate_hz)
                                wav_file.setsampwidth(result.sample_width_bytes)
                                wav_file.setnchannels(result.num_channels)
                                wav_params_set = True

                            wav_file.writeframes(result.audio_bytes)
                except Exception as e:
                    if not wav_params_set:
                        # Set default parameters so exception can propagate
                        wav_file.setframerate(22050)
                        wav_file.setsampwidth(2)
                        wav_file.setnchannels(1)

                    raise e

            wav_bytes = wav_io.getvalue()

        return wav_bytes


# TODO manually check gender of each voice and add below
Mimic3TTSPluginConfig = {
    'af-za': [
        {"offline": True,
         'display_name': 'Google-Nwu - 7214',
         'gender': '',
         'speaker': '7214',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 8963',
         'gender': '',
         'speaker': '8963',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 7130',
         'gender': '',
         'speaker': '7130',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 8924',
         'gender': '',
         'speaker': '8924',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 8148',
         'gender': '',
         'speaker': '8148',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 1919',
         'gender': '',
         'speaker': '1919',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 2418',
         'gender': '',
         'speaker': '2418',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 6590',
         'gender': '',
         'speaker': '6590',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 0184',
         'gender': '',
         'speaker': '0184',
         "priority": 50,
         'voice': 'af_ZA/google-nwu_low'}
    ],
    'bn': [
        {"offline": True,
         'display_name': 'Multi - Rm',
         'gender': '',
         'speaker': 'rm',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 03042',
         'gender': '',
         'speaker': '03042',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 00737',
         'gender': '',
         'speaker': '00737',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 01232',
         'gender': '',
         'speaker': '01232',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 02194',
         'gender': '',
         'speaker': '02194',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 3108',
         'gender': '',
         'speaker': '3108',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 3713',
         'gender': '',
         'speaker': '3713',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 1010',
         'gender': '',
         'speaker': '1010',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 00779',
         'gender': '',
         'speaker': '00779',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 9169',
         'gender': '',
         'speaker': '9169',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 4046',
         'gender': '',
         'speaker': '4046',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 5958',
         'gender': '',
         'speaker': '5958',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 01701',
         'gender': '',
         'speaker': '01701',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 4811',
         'gender': '',
         'speaker': '4811',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 0834',
         'gender': '',
         'speaker': '0834',
         "priority": 50,
         'voice': 'bn/multi_low'},
        {"offline": True,
         'display_name': 'Multi - 3958',
         'gender': '',
         'speaker': '3958',
         "priority": 50,
         'voice': 'bn/multi_low'}
    ],
    'de-de': [
        {"offline": True,
         'display_name': 'Thorsten',
         'gender': '',
         'speaker': 'default',
         "priority": 30,
         'voice': 'de_DE/thorsten_low'},
        {"offline": True,
         'display_name': 'Thorsten-Emotion - Amused',
         'gender': '',
         'speaker': 'amused',
         "priority": 45,
         'voice': 'de_DE/thorsten-emotion_low'},
        {"offline": True,
         'display_name': 'Thorsten-Emotion - Angry',
         'gender': '',
         'speaker': 'angry',
         "priority": 45,
         'voice': 'de_DE/thorsten-emotion_low'},
        {"offline": True,
         'display_name': 'Thorsten-Emotion - Disgusted',
         'gender': '',
         'speaker': 'disgusted',
         "priority": 45,
         'voice': 'de_DE/thorsten-emotion_low'},
        {"offline": True,
         'display_name': 'Thorsten-Emotion - Drunk',
         'gender': '',
         'speaker': 'drunk',
         "priority": 45,
         'voice': 'de_DE/thorsten-emotion_low'},
        {"offline": True,
         'display_name': 'Thorsten-Emotion - Neutral',
         'gender': '',
         'speaker': 'neutral',
         "priority": 45,
         'voice': 'de_DE/thorsten-emotion_low'},
        {"offline": True,
         'display_name': 'Thorsten-Emotion - Sleepy',
         'gender': '',
         'speaker': 'sleepy',
         "priority": 45,
         'voice': 'de_DE/thorsten-emotion_low'},
        {"offline": True,
         'display_name': 'Thorsten-Emotion - Surprised',
         'gender': '',
         'speaker': 'surprised',
         "priority": 45,
         'voice': 'de_DE/thorsten-emotion_low'},
        {"offline": True,
         'display_name': 'Thorsten-Emotion - Whisper',
         'gender': '',
         'speaker': 'whisper',
         "priority": 45,
         'voice': 'de_DE/thorsten-emotion_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Ramona Deininger',
         'gender': '',
         'speaker': 'ramona_deininger',
         "priority": 31,
         'voice': 'de_DE/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Karlsson',
         "priority": 31,
         'gender': '',
         'speaker': 'karlsson',
         'voice': 'de_DE/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Rebecca Braunert Plunkett',
         "priority": 31,
         'gender': '',
         'speaker': 'rebecca_braunert_plunkett',
         'voice': 'de_DE/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Eva K',
         "priority": 31,
         'gender': '',
         'speaker': 'eva_k',
         'voice': 'de_DE/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Angela Merkel',
         "priority": 31,
         'gender': '',
         'speaker': 'angela_merkel',
         'voice': 'de_DE/m-ailabs_low'}
    ],
    'el-gr': [
        {"offline": True,
         'display_name': 'Rapunzelina',
         "priority": 40,
         'gender': '',
         'speaker': 'default',
         'voice': 'el_GR/rapunzelina_low'}
    ],
    'en-gb': [
        {"offline": True,
         'display_name': 'Apope',
         "priority": 30,
         'gender': 'male',
         'speaker': 'default',
         'voice': 'en_UK/apope_low'}
    ],
    'en-us': [
        {"offline": True,
         'display_name': 'Cmu-Arctic - Slt',
         'gender': 'female',
         "priority": 40,
         'speaker': 'slt',
         'voice': 'en_US/cmu-arctic_low'},
        {"offline": True,
         'display_name': 'Cmu-Arctic - Awb',
         'gender': 'male',
         "priority": 40,
         'speaker': 'awb',
         'voice': 'en_US/cmu-arctic_low'},
        {"offline": True,
         'display_name': 'Cmu-Arctic - Rms',
         'gender': 'male',
         "priority": 40,
         'speaker': 'rms',
         'voice': 'en_US/cmu-arctic_low'},
        {"offline": True,
         'display_name': 'Cmu-Arctic - Ksp',
         'gender': 'male',
         "priority": 40,
         'speaker': 'ksp',
         'voice': 'en_US/cmu-arctic_low'},
        {"offline": True,
         'display_name': 'Cmu-Arctic - Clb',
         'gender': 'female',
         "priority": 40,
         'speaker': 'clb',
         'voice': 'en_US/cmu-arctic_low'},
        {"offline": True,
         'display_name': 'Cmu-Arctic - Aew',
         'gender': 'male',
         "priority": 40,
         'speaker': 'aew',
         'voice': 'en_US/cmu-arctic_low'},
        {"offline": True,
         'display_name': 'Cmu-Arctic - Bdl',
         'gender': 'male',
         "priority": 40,
         'speaker': 'bdl',
         'voice': 'en_US/cmu-arctic_low'},
        {"offline": True,
         'display_name': 'Cmu-Arctic - Lnh',
         'gender': 'female',
         "priority": 40,
         'speaker': 'lnh',
         'voice': 'en_US/cmu-arctic_low'},
        {"offline": True,
         'display_name': 'Hifi-Tts - 9017',
         'gender': 'male',
         "priority": 40,
         'speaker': '9017',
         'voice': 'en_US/hifi-tts_low'},
        {"offline": True,
         'display_name': 'Hifi-Tts - 6097',
         'gender': 'male',
         "priority": 40,
         'speaker': '6097',
         'voice': 'en_US/hifi-tts_low'},
        {"offline": True,
         'display_name': 'Hifi-Tts - 92',
         'gender': 'female',
         "priority": 40,
         'speaker': '92',
         'voice': 'en_US/hifi-tts_low'},
        {"offline": True,
         'display_name': 'Ljspeech',
         'gender': 'female',
         "priority": 45,
         'speaker': 'default',
         'voice': 'en_US/ljspeech_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Elliot Miller',
         'gender': 'male',
         "priority": 40,
         'speaker': 'elliot_miller',
         'voice': 'en_US/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Judy Bieber',
         'gender': 'female',
         'speaker': 'judy_bieber',
         "priority": 40,
         'voice': 'en_US/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Mary Ann',
         'gender': 'female',
         'speaker': 'mary_ann',
         "priority": 45,
         'voice': 'en_US/m-ailabs_low'},
        {"offline": True,
         'display_name': 'Vctk - P239',
         'gender': '',
         'speaker': 'p239',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P236',
         'gender': '',
         'speaker': 'p236',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P264',
         'gender': '',
         'speaker': 'p264',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P250',
         'gender': '',
         'speaker': 'p250',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P259',
         'gender': '',
         'speaker': 'p259',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P247',
         'gender': '',
         'speaker': 'p247',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P261',
         'gender': '',
         'speaker': 'p261',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P263',
         'gender': '',
         'speaker': 'p263',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P283',
         'gender': '',
         'speaker': 'p283',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P274',
         'gender': '',
         'speaker': 'p274',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P286',
         'gender': '',
         'speaker': 'p286',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P276',
         'gender': '',
         'speaker': 'p276',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P270',
         'gender': '',
         'speaker': 'p270',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P281',
         'gender': '',
         'speaker': 'p281',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P277',
         'gender': '',
         'speaker': 'p277',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P231',
         'gender': '',
         'speaker': 'p231',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P238',
         'gender': '',
         'speaker': 'p238',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P271',
         'gender': '',
         'speaker': 'p271',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P257',
         'gender': '',
         'speaker': 'p257',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P273',
         'gender': '',
         'speaker': 'p273',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P284',
         'gender': '',
         'speaker': 'p284',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P329',
         'gender': '',
         'speaker': 'p329',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P361',
         'gender': '',
         'speaker': 'p361',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P287',
         'gender': '',
         'speaker': 'p287',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P360',
         'gender': '',
         'speaker': 'p360',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P374',
         'gender': '',
         'speaker': 'p374',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P376',
         'gender': '',
         'speaker': 'p376',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P310',
         'gender': '',
         'speaker': 'p310',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P304',
         'gender': '',
         'speaker': 'p304',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P340',
         'gender': '',
         'speaker': 'p340',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P347',
         'gender': '',
         'speaker': 'p347',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P330',
         'gender': '',
         'speaker': 'p330',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P308',
         'gender': '',
         'speaker': 'p308',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P314',
         'gender': '',
         'speaker': 'p314',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P317',
         'gender': '',
         'speaker': 'p317',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P339',
         'gender': '',
         'speaker': 'p339',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P311',
         'gender': '',
         'speaker': 'p311',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P294',
         'gender': '',
         'speaker': 'p294',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P305',
         'gender': '',
         'speaker': 'p305',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P266',
         'gender': '',
         'speaker': 'p266',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P335',
         'gender': '',
         'speaker': 'p335',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P334',
         'gender': '',
         'speaker': 'p334',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P318',
         'gender': '',
         'speaker': 'p318',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P323',
         'gender': '',
         'speaker': 'p323',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P351',
         'gender': '',
         'speaker': 'p351',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P333',
         'gender': '',
         'speaker': 'p333',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P313',
         'gender': '',
         'speaker': 'p313',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P316',
         'gender': '',
         'speaker': 'p316',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P244',
         'gender': '',
         'speaker': 'p244',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P307',
         'gender': '',
         'speaker': 'p307',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P363',
         'gender': '',
         'speaker': 'p363',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P336',
         'gender': '',
         'speaker': 'p336',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P312',
         'gender': '',
         'speaker': 'p312',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P267',
         'gender': '',
         'speaker': 'p267',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P297',
         'gender': '',
         'speaker': 'p297',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P275',
         'gender': '',
         'speaker': 'p275',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P295',
         'gender': '',
         'speaker': 'p295',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P288',
         'gender': '',
         'speaker': 'p288',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P258',
         'gender': '',
         'speaker': 'p258',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P301',
         'gender': '',
         'speaker': 'p301',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P232',
         'gender': '',
         'speaker': 'p232',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P292',
         'gender': '',
         'speaker': 'p292',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P272',
         'gender': '',
         'speaker': 'p272',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P278',
         'gender': '',
         'speaker': 'p278',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P280',
         'gender': '',
         'speaker': 'p280',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P341',
         'gender': '',
         'speaker': 'p341',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P268',
         'gender': '',
         'speaker': 'p268',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P298',
         'gender': '',
         'speaker': 'p298',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P299',
         'gender': '',
         'speaker': 'p299',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P279',
         'gender': '',
         'speaker': 'p279',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P285',
         'gender': '',
         'speaker': 'p285',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P326',
         'gender': '',
         'speaker': 'p326',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P300',
         'gender': '',
         'speaker': 'p300',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - S5',
         'gender': '',
         'speaker': 's5',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P230',
         'gender': '',
         'speaker': 'p230',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P254',
         'gender': '',
         'speaker': 'p254',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P269',
         'gender': '',
         'speaker': 'p269',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P293',
         'gender': '',
         'speaker': 'p293',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P252',
         'gender': '',
         'speaker': 'p252',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P345',
         'gender': '',
         'speaker': 'p345',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P262',
         'gender': '',
         'speaker': 'p262',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P243',
         'gender': '',
         'speaker': 'p243',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P227',
         'gender': '',
         'speaker': 'p227',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P343',
         'gender': '',
         'speaker': 'p343',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P255',
         'gender': '',
         'speaker': 'p255',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P229',
         'gender': '',
         'speaker': 'p229',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P240',
         'gender': '',
         'speaker': 'p240',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P248',
         'gender': '',
         'speaker': 'p248',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P253',
         'gender': '',
         'speaker': 'p253',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P233',
         'gender': '',
         'speaker': 'p233',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P228',
         'gender': '',
         'speaker': 'p228',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P251',
         'gender': '',
         'speaker': 'p251',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P282',
         'gender': '',
         'speaker': 'p282',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P246',
         'gender': '',
         'speaker': 'p246',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P234',
         'gender': '',
         'speaker': 'p234',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P226',
         'gender': '',
         'speaker': 'p226',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P260',
         'gender': '',
         'speaker': 'p260',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P245',
         'gender': '',
         'speaker': 'p245',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P241',
         'gender': '',
         'speaker': 'p241',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P303',
         'gender': '',
         'speaker': 'p303',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P265',
         'gender': '',
         'speaker': 'p265',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P306',
         'gender': '',
         'speaker': 'p306',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P237',
         'gender': '',
         'speaker': 'p237',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P249',
         'gender': '',
         'speaker': 'p249',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P256',
         'gender': '',
         'speaker': 'p256',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P302',
         'gender': '',
         'speaker': 'p302',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P364',
         'gender': '',
         'speaker': 'p364',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P225',
         'gender': '',
         'speaker': 'p225',
         "priority": 41,
         'voice': 'en_US/vctk_low'},
        {"offline": True,
         'display_name': 'Vctk - P362',
         'gender': '',
         'speaker': 'p362',
         "priority": 41,
         'voice': 'en_US/vctk_low'}
    ],
    'es-es': [
        {"offline": True,
         'display_name': 'Carlfm',
         'gender': '',
         'speaker': 'default',
         "priority": 40,
         'voice': 'es_ES/carlfm_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Tux',
         'gender': '',
         'speaker': 'tux',
         "priority": 40,
         'voice': 'es_ES/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Victor Villarraza',
         'gender': '',
         'speaker': 'victor_villarraza',
         "priority": 40,
         'voice': 'es_ES/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Karen Savage',
         'gender': '',
         'speaker': 'karen_savage',
         "priority": 40,
         'voice': 'es_ES/m-ailabs_low'}
    ],
    'fa': [
        {"offline": True,
         'display_name': 'Haaniye',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'fa/haaniye_low'}
    ],
    'fi-fi': [
        {"offline": True,
         'display_name': 'Harri-Tapani-Ylilammi',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'fi_FI/harri-tapani-ylilammi_low'}
    ],
    'fr-fr': [
        {"offline": True,
         'display_name': 'M-Ailabs - Ezwa',
         'gender': '',
         'speaker': 'ezwa',
         "priority": 40,
         'voice': 'fr_FR/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Nadine Eckert Boulet',
         'gender': '',
         "priority": 40,
         'speaker': 'nadine_eckert_boulet',
         'voice': 'fr_FR/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Bernard',
         'gender': '',
         "priority": 40,
         'speaker': 'bernard',
         'voice': 'fr_FR/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Zeckou',
         'gender': '',
         'speaker': 'zeckou',
         "priority": 40,
         'voice': 'fr_FR/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Gilles G Le Blanc',
         'gender': '',
         "priority": 40,
         'speaker': 'gilles_g_le_blanc',
         'voice': 'fr_FR/m-ailabs_low'},
        {"offline": True,
         'display_name': 'Siwis',
         'gender': '',
         'speaker': 'default',
         "priority": 40,
         'voice': 'fr_FR/siwis_low'},
        {"offline": True,
         'display_name': 'Tom',
         'gender': '',
         "priority": 40,
         'speaker': 'default',
         'voice': 'fr_FR/tom_low'}
    ],
    'gu-in': [
        {"offline": True,
         'display_name': 'Cmu-Indic - Cmu Indic Guj Dp',
         'gender': '',
         'speaker': 'cmu_indic_guj_dp',
         "priority": 50,
         'voice': 'gu_IN/cmu-indic_low'},
        {"offline": True,
         'display_name': 'Cmu-Indic - Cmu Indic Guj Ad',
         'gender': '',
         'speaker': 'cmu_indic_guj_ad',
         "priority": 50,
         'voice': 'gu_IN/cmu-indic_low'},
        {"offline": True,
         'display_name': 'Cmu-Indic - Cmu Indic Guj Kt',
         'gender': '',
         "priority": 50,
         'speaker': 'cmu_indic_guj_kt',
         'voice': 'gu_IN/cmu-indic_low'}
    ],
    'ha-ne': [
        {"offline": True,
         'display_name': 'Openbible',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'ha_NE/openbible_low'}
    ],
    'hu-hu': [
        {"offline": True,
         'display_name': 'Diana-Majlinger',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'hu_HU/diana-majlinger_low'}
    ],
    'it-it': [
        {"offline": True,
         'display_name': 'Riccardo-Fasol',
         'gender': '',
         'speaker': 'default',
         "priority": 40,
         'voice': 'it_IT/riccardo-fasol_low'},
        {"offline": True,
         'display_name': 'Mls - 1595',
         'gender': '',
         'speaker': '1595',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 4974',
         'gender': '',
         "priority": 50,
         'speaker': '4974',
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 4998',
         'gender': '',
         "priority": 50,
         'speaker': '4998',
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 6807',
         'gender': '',
         "priority": 50,
         'speaker': '6807',
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 1989',
         'gender': '',
         'speaker': '1989',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 2033',
         'gender': '',
         "priority": 50,
         'speaker': '2033',
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 2019',
         'gender': '',
         'speaker': '2019',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 659',
         'gender': '',
         "priority": 50,
         'speaker': '659',
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 4649',
         'gender': '',
         'speaker': '4649',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 9772',
         'gender': '',
         'speaker': '9772',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 1725',
         'gender': '',
         'speaker': '1725',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 10446',
         'gender': '',
         'speaker': '10446',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 6348',
         'gender': '',
         'speaker': '6348',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 6001',
         'gender': '',
         'speaker': '6001',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 9185',
         'gender': '',
         'speaker': '9185',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 8842',
         'gender': '',
         'speaker': '8842',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 8828',
         'gender': '',
         'speaker': '8828',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 12428',
         'gender': '',
         'speaker': '12428',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 8181',
         'gender': '',
         'speaker': '8181',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 7440',
         'gender': '',
         'speaker': '7440',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 8207',
         'gender': '',
         'speaker': '8207',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 277',
         'gender': '',
         'speaker': '277',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 5421',
         'gender': '',
         'speaker': '5421',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 12804',
         'gender': '',
         'speaker': '12804',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 4705',
         'gender': '',
         'speaker': '4705',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 7936',
         'gender': '',
         'speaker': '7936',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 844',
         'gender': '',
         'speaker': '844',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 6299',
         'gender': '',
         'speaker': '6299',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 644',
         'gender': '',
         'speaker': '644',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 8384',
         'gender': '',
         'speaker': '8384',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 1157',
         'gender': '',
         'speaker': '1157',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 7444',
         'gender': '',
         'speaker': '7444',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 643',
         'gender': '',
         'speaker': '643',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 4971',
         'gender': '',
         'speaker': '4971',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 4975',
         'gender': '',
         'speaker': '4975',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 6744',
         'gender': '',
         'speaker': '6744',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 8461',
         'gender': '',
         'speaker': '8461',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 7405',
         'gender': '',
         'speaker': '7405',
         "priority": 50,
         'voice': 'it_IT/mls_low'},
        {"offline": True,
         'display_name': 'Mls - 5010',
         'gender': '',
         'speaker': '5010',
         "priority": 50,
         'voice': 'it_IT/mls_low'}
    ],
    'jv-id': [
        {"offline": True,
         'display_name': 'Google-Gmu - 07875',
         'gender': '',
         'speaker': '07875',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 05522',
         'gender': '',
         'speaker': '05522',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 03424',
         'gender': '',
         'speaker': '03424',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 06510',
         'gender': '',
         'speaker': '06510',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 03314',
         'gender': '',
         'speaker': '03314',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 03187',
         'gender': '',
         'speaker': '03187',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 07638',
         'gender': '',
         'speaker': '07638',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 06207',
         'gender': '',
         'speaker': '06207',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 08736',
         'gender': '',
         'speaker': '08736',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 04679',
         'gender': '',
         'speaker': '04679',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 01392',
         'gender': '',
         'speaker': '01392',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 05540',
         'gender': '',
         'speaker': '05540',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 05219',
         'gender': '',
         'speaker': '05219',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 00027',
         'gender': '',
         'speaker': '00027',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 00264',
         'gender': '',
         'speaker': '00264',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 09724',
         'gender': '',
         'speaker': '09724',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 04588',
         'gender': '',
         'speaker': '04588',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 09039',
         'gender': '',
         'speaker': '09039',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 04285',
         'gender': '',
         'speaker': '04285',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 05970',
         'gender': '',
         'speaker': '05970',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 08305',
         'gender': '',
         'speaker': '08305',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 04982',
         'gender': '',
         'speaker': '04982',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 08002',
         'gender': '',
         'speaker': '08002',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 06080',
         'gender': '',
         'speaker': '06080',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 07765',
         'gender': '',
         'speaker': '07765',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 02326',
         'gender': '',
         'speaker': '02326',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 03727',
         'gender': '',
         'speaker': '03727',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 04175',
         'gender': '',
         'speaker': '04175',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 06383',
         'gender': '',
         'speaker': '06383',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 02884',
         'gender': '',
         'speaker': '02884',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 06941',
         'gender': '',
         'speaker': '06941',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 08178',
         'gender': '',
         'speaker': '08178',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 00658',
         'gender': '',
         'speaker': '00658',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 04715',
         'gender': '',
         'speaker': '04715',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 05667',
         'gender': '',
         'speaker': '05667',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 01519',
         'gender': '',
         'speaker': '01519',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 07335',
         'gender': '',
         'speaker': '07335',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 02059',
         'gender': '',
         'speaker': '02059',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'},
        {"offline": True,
         'display_name': 'Google-Gmu - 01932',
         'gender': '',
         'speaker': '01932',
         "priority": 50,
         'voice': 'jv_ID/google-gmu_low'}
    ],
    'ko-ko': [
        {"offline": True,
         'display_name': 'Kss',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'ko_KO/kss_low'}
    ],
    'ne-np': [
        {"offline": True,
         'display_name': 'Ne-Google - 0546',
         'gender': '',
         'speaker': '0546',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 3614',
         'gender': '',
         'speaker': '3614',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 2099',
         'gender': '',
         'speaker': '2099',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 3960',
         'gender': '',
         'speaker': '3960',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 6834',
         'gender': '',
         'speaker': '6834',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 7957',
         'gender': '',
         'speaker': '7957',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 6329',
         'gender': '',
         'speaker': '6329',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 9407',
         'gender': '',
         'speaker': '9407',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 6587',
         'gender': '',
         'speaker': '6587',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 0258',
         'gender': '',
         'speaker': '0258',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 2139',
         'gender': '',
         'speaker': '2139',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 5687',
         'gender': '',
         'speaker': '5687',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 0283',
         'gender': '',
         'speaker': '0283',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 3997',
         'gender': '',
         'speaker': '3997',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 3154',
         'gender': '',
         'speaker': '3154',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 0883',
         'gender': '',
         'speaker': '0883',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 2027',
         'gender': '',
         'speaker': '2027',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'},
        {"offline": True,
         'display_name': 'Ne-Google - 0649',
         'gender': '',
         'speaker': '0649',
         "priority": 50,
         'voice': 'ne_NP/ne-google_low'}
    ],
    'nl': [
        {"offline": True,
         'display_name': 'Bart-De-Leeuw',
         'gender': '',
         'speaker': 'default',
         "priority": 40,
         'voice': 'nl/bart-de-leeuw_low'},
        {"offline": True,
         'display_name': 'Flemishguy',
         'gender': '',
         'speaker': 'default',
         "priority": 40,
         'voice': 'nl/flemishguy_low'},
        {"offline": True,
         'display_name': 'Nathalie',
         'gender': '',
         'speaker': 'default',
         "priority": 40,
         'voice': 'nl/nathalie_low'},
        {"offline": True,
         'display_name': 'Pmk',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'nl/pmk_low'},
        {"offline": True,
         'display_name': 'Rdh',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'nl/rdh_low'}
    ],
    'pl-pl': [
        {"offline": True,
         'display_name': 'M-Ailabs - Piotr Nater',
         'gender': '',
         'speaker': 'piotr_nater',
         "priority": 40,
         'voice': 'pl_PL/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Nina Brown',
         'gender': '',
         'speaker': 'nina_brown',
         "priority": 40,
         'voice': 'pl_PL/m-ailabs_low'}
    ],
    'ru-ru': [
        {"offline": True,
         'display_name': 'Multi - Hajdurova',
         'gender': '',
         'speaker': 'hajdurova',
         "priority": 50,
         'voice': 'ru_RU/multi_low'},
        {"offline": True,
         'display_name': 'Multi - Minaev',
         'gender': '',
         'speaker': 'minaev',
         "priority": 50,
         'voice': 'ru_RU/multi_low'},
        {"offline": True,
         'display_name': 'Multi - Nikolaev',
         'gender': '',
         'speaker': 'nikolaev',
         "priority": 50,
         'voice': 'ru_RU/multi_low'}
    ],
    'sw': [
        {"offline": True,
         'display_name': 'Lanfrica',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'sw/lanfrica_low'}
    ],
    'te-in': [
        {"offline": True,
         'display_name': 'Cmu-Indic - Ss',
         'gender': '',
         'speaker': 'ss',
         "priority": 50,
         'voice': 'te_IN/cmu-indic_low'},
        {"offline": True,
         'display_name': 'Cmu-Indic - Sk',
         'gender': '',
         'speaker': 'sk',
         "priority": 50,
         'voice': 'te_IN/cmu-indic_low'},
        {"offline": True,
         'display_name': 'Cmu-Indic - Kpn',
         'gender': '',
         'speaker': 'kpn',
         "priority": 50,
         'voice': 'te_IN/cmu-indic_low'}
    ],
    'tn-za': [
        {"offline": True,
         'display_name': 'Google-Nwu - 1932',
         'gender': '',
         'speaker': '1932',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 0045',
         'gender': '',
         'speaker': '0045',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 3342',
         'gender': '',
         'speaker': '3342',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 4850',
         'gender': '',
         'speaker': '4850',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 6206',
         'gender': '',
         'speaker': '6206',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 3629',
         'gender': '',
         'speaker': '3629',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 9061',
         'gender': '',
         'speaker': '9061',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 6116',
         'gender': '',
         'speaker': '6116',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 7674',
         'gender': '',
         'speaker': '7674',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 0378',
         'gender': '',
         'speaker': '0378',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 5628',
         'gender': '',
         'speaker': '5628',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 8333',
         'gender': '',
         'speaker': '8333',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 8512',
         'gender': '',
         'speaker': '8512',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 0441',
         'gender': '',
         'speaker': '0441',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 6459',
         'gender': '',
         'speaker': '6459',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 4506',
         'gender': '',
         'speaker': '4506',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 7866',
         'gender': '',
         'speaker': '7866',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 8532',
         'gender': '',
         'speaker': '8532',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 2839',
         'gender': '',
         'speaker': '2839',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 7896',
         'gender': '',
         'speaker': '7896',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 1498',
         'gender': '',
         'speaker': '1498',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 1483',
         'gender': '',
         'speaker': '1483',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 8914',
         'gender': '',
         'speaker': '8914',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 6234',
         'gender': '',
         'speaker': '6234',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 9365',
         'gender': '',
         'speaker': '9365',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'},
        {"offline": True,
         'display_name': 'Google-Nwu - 7693',
         'gender': '',
         'speaker': '7693',
         "priority": 50,
         'voice': 'tn_ZA/google-nwu_low'}
    ],
    'uk-uk': [
        {"offline": True,
         'display_name': 'M-Ailabs - Obruchov',
         'gender': '',
         'speaker': 'obruchov',
         "priority": 40,
         'voice': 'uk_UK/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Shepel',
         'gender': '',
         'speaker': 'shepel',
         "priority": 40,
         'voice': 'uk_UK/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Loboda',
         'gender': '',
         "priority": 40,
         'speaker': 'loboda',
         'voice': 'uk_UK/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Miskun',
         'gender': '',
         'speaker': 'miskun',
         "priority": 40,
         'voice': 'uk_UK/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Sumska',
         'gender': '',
         'speaker': 'sumska',
         "priority": 40,
         'voice': 'uk_UK/m-ailabs_low'},
        {"offline": True,
         'display_name': 'M-Ailabs - Pysariev',
         'gender': '',
         'speaker': 'pysariev',
         "priority": 40,
         'voice': 'uk_UK/m-ailabs_low'}
    ],
    'vi-vn': [
        {"offline": True,
         'display_name': 'Vais1000',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'vi_VN/vais1000_low'}
    ],
    'yo': [
        {"offline": True,
         'display_name': 'Openbible',
         'gender': '',
         'speaker': 'default',
         "priority": 50,
         'voice': 'yo/openbible_low'}
    ]
}
